@@ -295,7 +295,9 @@ function File:finish()
             end
             item.display_name = display_name
             this_mod.section = item
-            this_mod.kinds:add_kind(display_name,display_name,nil,item)
+            -- the purpose of this little hack is to properly distinguish
+            -- between built-in kinds and any user-defined kinds.
+            this_mod.kinds:add_kind(display_name,display_name..' ',nil,item)
             this_mod.sections:append(item)
             this_mod.sections.by_name[lookup_name:gsub('%A','_')] = item
          end
